@@ -175,10 +175,10 @@ method described by Leacock and Chodorow (1998).
 
 This module computes the semantic relatedness of two concepts in 
 the UMLS according to a method described by Leacock and Chodorow 
-(1998). This method counts up the number of edges between the 
-concepts in the a specified view of the UMLS.  This value is then 
-scaled by the maximum depth of this view. A relatedness value is 
-obtained by taking the negative log of this scaled value.
+(1998). The relatedness measure proposed by Leacock and Chodorow 
+is S<-log (length / (2 * D))>, where length is the length of the 
+shortest path between the two synsets (using node-counting) and 
+D is the maximum depth of the taxonomy.
 
 =head1 USAGE
 
